from distutils.core import setup

setup(
	name		= 'nesterMax',
	version 	= '1.1.0',
	py_modules 	= ['nesterMax'],
	author		= 'Max',
	author_email	= 'bart30508@gmail.com',
	url		= 'http://www.headfirstlabs.com',
	description	= 'a simple printer of nested lists',
     )